@@ -50,11 +50,7 @@ def process_iter(proc, cmd=""):
             proc.wait()
             if proc.returncode not in (0, None):
                 sys.stderr.write("cmd was:%s\n" % cmd)
-                raise ProcessException(proc.stderr.read())
-            s = proc.stderr.read().strip()
-            if len(s) != 0:
-                sys.stderr.write(str(s))
-                sys.stderr.write('\n')
+                raise ProcessException(cmd)
 
 def nopen(f, mode="r"):
     r"""
@@ -90,13 +86,17 @@ def nopen(f, mode="r"):
     if f.startswith("|"):
         # using shell explicitly makes things like process substitution work:
         # http://stackoverflow.com/questions/7407667/python-subprocess-subshells-and-redirection
-        p = Popen(f[1:], stdout=PIPE, stdin=PIPE, stderr=PIPE, shell=True,
-                close_fds=False, executable=os.environ.get('SHELL'))
+        # use sys.stderr so we dont have to worry about checking it...
+        p = Popen(f[1:], stdout=PIPE, stdin=PIPE,
+                  stderr=sys.stderr if mode == "r" else PIPE,
+                  shell=True, bufsize=-1, # use system default for buffering
+                  close_fds=False, executable=os.environ.get('SHELL'))
         if sys.version_info.major > 2:
             import io
             p.stdout = io.TextIOWrapper(p.stdout)
             p.stdin = io.TextIOWrapper(p.stdin)
-            p.stderr = io.TextIOWrapper(p.stderr)
+            if mode != "r":
+                p.stderr = io.TextIOWrapper(p.stderr)
 
         if mode and mode[0] == "r":
             return process_iter(p, f[1:])
